@@ -112,7 +112,9 @@ void xml_quitSymbols()
   {
     assert0(CfgSyms != (symbol*)NULL,"xmlSymbols not initialized");
     if( CfgSyms != (symbol*)NULL ) FreeMem(CfgSyms);
+    CfgSyms = (symbol*)NULL;
     if( PrdSyms != (symbol*)NULL ) FreeMem(PrdSyms);
+    PrdSyms = (symbol*)NULL;
   }
 }
 
