@@ -1141,7 +1141,7 @@ void HS_get(HS_Itr itr, HS_Elm* elm)
                                  itr = HS_CREATE_ITR(set);    \
                                  HS_EMPTY_ITR(itr)            \
                                  ? (HS_DROP_ITR(itr), False)  \
-                                 : (HS_GET(itr, &elm), True); \
+                                 : (HS_GET(itr, ((StdCPtr)&elm)), True); \
                                )
 
 /*I======================= Sets & Relations ================================= */
