@@ -394,6 +394,12 @@ PLR_Pdf PLR_createPdf(PLR_Tab PTab, StdCPtr extCfg)
   Parser->nxttok   = C_True;
   Parser->StackS   = (OT_Tab)NULL;
   Parser->StackV   = (OT_Tab)NULL;
+  Parser->get      = NULL;
+  Parser->curSy    = NULL;
+  Parser->redVal   = NULL;
+  Parser->shiftVal = NULL;
+  Parser->error    = NULL;
+  Parser->debug    = NULL;
   return( Parser );
 }
 
@@ -1072,7 +1078,7 @@ ROW(int) PLR_actionValues(PLR_Tab PTab, int stateId)
 /* action value ( error=-2|accept=-1|prodId, tokenId|startId|-1 ) ...
    of state 'stateId' in parse table 'PTab'; allocs result row 
    [stateId=0..StateCnt-1, prodId=0..PCnt-1, 
-    tokenId=0..TokenCnt-1, startId=0..StartCnt-1] 
+    tokenId=0..TokenCnt-1, startId=TokenCnt..TokenCnt+StartCnt-1] 
 */
 { 
   BUG_NULL(PTab);
@@ -1123,7 +1129,8 @@ ROW(int) PLR_actionValues(PLR_Tab PTab, int stateId)
           if( action == prodcnt + 2 )
           {
             OT_PUSH(-1,result);
-            OT_PUSH(e_entry-PLR_T_IMP(PTab)->Kfg->TkCnt-1,result);
+            //OT_PUSH(e_entry-PLR_T_IMP(PTab)->Kfg->TkCnt-1,result);
+            OT_PUSH(e_entry-1,result);
           }
           else
           if( action <= prodcnt )
