@@ -595,7 +595,7 @@ void PLR_Src_Modul(string Environ, PLR_Tab PTab)
 
   BUG_NULL(PTab); BUG_NULL(PLR_T_IMP(PTab)->Kfg);
   BUG_NULL(PLR_T_IMP(PTab)->Kfg->language);
-  fid = Str_printf("%s.ltbl",PLR_T_IMP(PTab)->Kfg->language);
+  fid = Str_printf("%s.ptbl",PLR_T_IMP(PTab)->Kfg->language);
   fp = OpenPath(Environ,fid,"","wt");
   PLR_Src_Source(fp,fid,PTab);
   fclose(fp);
@@ -676,6 +676,17 @@ PLR_Tab PLR_getTab(string Language)
   return( tab );
 }
 
+PLR_Tab PLR_getTab_file(string file)
+/* loads a parse table from 'file'
+*/
+{ PARSETAB* tab; 
+  BinImg_T  img = fgetBgn("",file,"");
+  fgetHeader(img,"pim",1,0);
+  tab = (PARSETAB*)PLR_fgetTab_bin(img);
+  fgetEnd(img);
+  return( tab );
+}
+
 PLR_Tab PLR_getTab_env(string Environ, string Language)
 /* loads a parse table named 'Language' 
    from image [$'Environ'/]<Language>.pim 
