@@ -601,14 +601,14 @@ PT_Term PT_r_find
         if( PT_T_TYP(PTree) >= 0 )
         { PTERM* ts;
           for( ts = PT_T_SUB(PTree); ts != (PTERM*)NULL; ts = PT_T_NXT(ts) )
-	    if( ( rt = PT_r_find(ts,pred,any) ) != (PT_Term)NULL )
-	      return( rt );
+            if( ( rt = PT_r_find(ts,pred,any) ) != (PT_Term)NULL )
+              return( rt );
         }
         else
         { List(PT_Term) ts;
           for( ts = PT_T_LST(PTree); ! empty(ts); ts = rst(ts) )
-	    if( ( rt = PT_r_find(fst(PT_Term,ts),pred,any) ) != (PT_Term)NULL )
-	      return( rt );
+            if( ( rt = PT_r_find(fst(PT_Term,ts),pred,any) ) != (PT_Term)NULL )
+              return( rt );
         }
       }
     }
@@ -1013,7 +1013,7 @@ static bool CPT_equal(PT_Term left, PT_Term right)
           tl = (PTERM*)PT_eqFilter(PT_T_NXT(tl)), 
           tr = (PTERM*)PT_eqFilter(PT_T_NXT(tr)) 
         ) 
-	    if( ! CPT_equal(tl,tr) ) return( False );
+        if( ! CPT_equal(tl,tr) ) return( False );
           return( primEqual(tl,tr) );
       }
       else return( CFG_NTM(PT_M_STP(left)) == CFG_NTM(PT_M_STP(right)) );
@@ -1039,8 +1039,8 @@ static bool XPT_equal(PT_Term left, PT_Term right)
           ! empty(tl) && ! empty(tr);
           tl = XPT_eqFilter(rst(tl)), tr = XPT_eqFilter(rst(tr)) 
         ) 
-	  if( ! XPT_equal(fst(PT_Term,tl),fst(PT_Term,tr)) ) return( False );
-        return( primEqual(tl,tr) );
+        if( ! XPT_equal(fst(PT_Term,tl),fst(PT_Term,tr)) ) return( False );
+          return( primEqual(tl,tr) );
       }
       else return( CFG_NTM(PT_M_STP(left)) == CFG_NTM(PT_M_STP(right)) );
     }
@@ -1186,7 +1186,7 @@ void PT_fgetT(BinImg_T img, PT_Term* PTree)
       t = PT_T_SUB_PTR(*PTree);
       for( i=0; i < cnt; ++i )
       { 
-        fgetReference(img,(PT_Term*)(&ts),PT_fgetT);
+        fgetReference(img,(PT_Term*)((StdCPtr)&ts),PT_fgetT);
         *t = ts; t = PT_T_NXT_PTR(ts);
       }
     }
@@ -1195,7 +1195,7 @@ void PT_fgetT(BinImg_T img, PT_Term* PTree)
       t = PT_T_LST_PTR(*PTree);
       for( i=0; i < cnt; ++i )
       { 
-        fgetReference(img,(PT_Term*)(&ts),PT_fgetT);
+        fgetReference(img,(PT_Term*)((StdCPtr)&ts),PT_fgetT);
         *t = cons(ts,*t); t = rst_ref(*t);
       }
     }
@@ -1763,7 +1763,7 @@ void PT_getAllSymbols(void)
 */
 { long len, l=0; byte __HUGE* array;
   PT_GET_BUG;
-  getHuge((HugeCPtr*)(&array),&len);
+  getHuge((HugeCPtr*)((HugeCPtr)&array),&len);
   OT_T_INS(AbsSymbol,len);
   while( l < len )
   { symbol s = stringToSymbol((string)(&array[l]));
@@ -1861,7 +1861,7 @@ long __HUGE* PT_getAbsT(void)
 */
 { long len; long __HUGE* array;
   PT_GET_BUG;
-  getHuge((HugeCPtr*)(&array),&len);
+  getHuge((HugeCPtr*)((HugeCPtr)&array),&len);
   return array;
 }
 
