@@ -552,9 +552,10 @@ static unsigned long PTP_pass1_aux
   if( ! PT_isNonTerm(t) )
   {
     assert0
-	(
-	  PTP_colsep(ctx,(short)(*row),(short)(*col)) == 0,"missing token seperator"
-	);
+    (
+      PTP_colsep(ctx,(short)(*row),(short)(*col)) == 0,
+      "missing token seperator"
+    );
     PTP_tokpos(ctx,t,row,col,*ind);
     ctx->currtok = t;
     PTP_setNextTok(ctx->lookahead);
@@ -600,7 +601,7 @@ static void PTP_pass1
           c = *col; r = *row;
           PTP_swap((StdCPtr*)(&ctx->lookahead),(StdCPtr*)(&it)); 
           PTP_swap((StdCPtr*)(&ctx->currtok),(StdCPtr*)(&ct)); 
-          PTP_swap((StdCPtr*)(&ctx->nlflg),(StdCPtr*)(&nl));
+          PTP_swap((StdCPtr*)((StdCPtr)&ctx->nlflg),(StdCPtr*)((StdCPtr)&nl));
           for( ts = PT_parts(tree); ts != (PT_Term)NULL; ts = PT_next(ts) )
             PTP_updpos(ctx,ts,r,&c);
           PTP_swap((StdCPtr*)(&it),(StdCPtr*)(&ctx->lookahead)); 
@@ -626,7 +627,7 @@ static void PTP_pass1
           c = *col; r = *row;
           PTP_swap((StdCPtr*)(&ctx->lookahead),(StdCPtr*)(&it)); 
           PTP_swap((StdCPtr*)(&ctx->currtok),(StdCPtr*)(&ct)); 
-          PTP_swap((StdCPtr*)(&ctx->nlflg),(StdCPtr*)(&nl));
+          PTP_swap((StdCPtr*)((StdCPtr)&ctx->nlflg),(StdCPtr*)((StdCPtr)&nl));
           for( ts = XPT_parts(tree); ! empty(ts); ts = rst(ts))
             PTP_updpos(ctx,fst(PT_Term,ts),r,&c);
           PTP_swap((StdCPtr*)(&it),(StdCPtr*)(&ctx->lookahead)); 
