@@ -29,10 +29,12 @@
 
 /*!
   <p><b>Identifier of other other</b>
+  <p><br>Separator between token ID and pattern<b>
 */
 
 /*DOC_INTERFACE*/
-#define SCN_TOK_Other "[other]"
+#define SCN_TOK_Other            "[other]"
+#define SCN_SEP_TOK_ID_PATTERN   '@'
 
 AbstractType( Scn_T ); /* Abstract scanner type */
 
@@ -230,6 +232,15 @@ void Scn_get_env(string Environ, string Language, Scn_T *x)
   fgetEnd(img);
 }
 
+void Scn_get_file(string file, Scn_T *x)
+/* loads a scanner definition from 'file' into 'x'
+*/
+{ BinImg_T img = fgetBgn("",file,"");
+  fgetHeader(img,"lim",1,0);
+  *x = Scn_fget_bin(img);
+  fgetEnd(img);
+}
+
 void Scn_fput_bin(BinImg_T img, Scn_T x)
 /* unloads scanner definition 'x'
    to binary image 'img' (reentrant)
