@@ -193,7 +193,7 @@ static SPP_T SPP_init_aux(MAP(long,symbol) pPreParMap)
   pPP->pCondRow      = OT_CREATE_ADT(long);
   pPP->pCurMacPar    = Sink_open();  
   pPP->pCurMacRow    = (ROW(_))NULL;
-  *pPP->szCurMacSep  = '\0';
+  pPP->szCurMacSep[0] = pPP->szCurMacSep[1] = pPP->szCurMacSep[2] = '\0';
   pPP->pCurPreParMap = pPreParMap;
   return pPP;
 }
@@ -637,10 +637,19 @@ int SPP_premac
                : SCN_FLG_RescanNone;
       }
       else
-      if( !strcmp(cTokNam,SPP_PREPAR(pPP,SPP_TOK_MACSEP)) && 
-          ( pPP->pCurMacRow == (ROW(symbol))NULL || strcmp(cTokVal,pPP->szCurMacSep) ) )
+      if( !strcmp(cTokNam,SPP_PREPAR(pPP,SPP_TOK_MACSEP)) /*&& 
+          ( pPP->pCurMacRow == (ROW(symbol))NULL || strcmp(cTokVal,pPP->szCurMacSep) )*/ )
       {
         SPP_setCurMacSep(pPP,cTokVal);
+        if( pPP->pCurMacRow != (ROW(symbol))NULL &&
+            strlen(pPP->szCurMacSep) == 0 && !Sink_empty(pPP->pCurMacPar) ) 
+        { string szPar = Sink_close(pPP->pCurMacPar);
+          *cMacVal = SPP_applyParameter(pPP,stringToSymbol(szPar),&pMacNam);
+          FreeMem(szPar); pPP->pCurMacPar = Sink_open();
+          return ( *cMacVal != (symbol)NULL )
+                 ? SPP_prepare_rescan(pPP,pStream,SCN_FLG_RescanString,pMacNam,cMacVal) 
+                 : SCN_FLG_RescanNone;
+        }
         *cMacVal = (symbol)NULL;
         return SCN_FLG_RescanNone;
       }
@@ -656,11 +665,12 @@ int SPP_premac
         }
         else
         {
-          if( strcmp(cTokNam,SPP_PREPAR(pPP,SPP_TOK_MACSEP)) && 
+          if( /*strcmp(cTokNam,SPP_PREPAR(pPP,SPP_TOK_MACSEP)) &&*/
+              strlen(pPP->szCurMacSep) > 0                   &&
               strcmp(cTokVal,pPP->szCurMacSep)                )
             Sink_printf(pPP->pCurMacPar,"%s",cTokVal);
           if( strlen(pPP->szCurMacSep) == 0                   ||
-              !strcmp(cTokNam,SPP_PREPAR(pPP,SPP_TOK_MACSEP)) || 
+              /*!strcmp(cTokNam,SPP_PREPAR(pPP,SPP_TOK_MACSEP)) ||*/
               !strcmp(cTokVal,pPP->szCurMacSep)                )
           { string szPar = Sink_close(pPP->pCurMacPar);
             *cMacVal = SPP_applyParameter(pPP,stringToSymbol(szPar),&pMacNam);
