@@ -7,6 +7,10 @@
 
 #if defined( _WIN32 ) || defined( _MSDOS ) || defined( MSDOS )
 #define STYX_CONFIG_OSMS
+#if _MSC_VER >= 1200
+#define HAVE_VSNPRINTF
+#define vsnprintf _vsnprintf
+#endif
 #endif
 
 #if defined( _MSDOS ) || defined( _WIN32 )
@@ -29,7 +33,7 @@
 #include <wctype.h>
 #include <windows.h>
 
-#define VERSION   "1.6"
+#define VERSION   "1.6.1"
 
 #else
 #ifndef HAVE_CONFIG_H
@@ -52,7 +56,7 @@
 #include <semaphore.h>
 #include <dlfcn.h>
 
-#define VERSION   "1.6"
+#define VERSION   "1.6.1"
 
 #else
 #include <config.h>
@@ -219,7 +223,7 @@
 #include <varargs.h>
 #endif
 
-#ifndef HAVE_STRERROR				  /* Otherwise use the table */
+#ifndef HAVE_STRERROR  /* Otherwise use the table */
 extern char *sys_errlist[];
 extern int sys_nerr;
 #endif
