@@ -744,6 +744,32 @@ RegSet_T RegSet_Plus(RegSet_T a)
   return c;
 }
 
+RegSet_T RegSet_Plus_ntimes(RegSet_T a, int n)
+/* iteration { a } n-times, n >= 0 */
+{ RegSet_T res = RegSet_Epsilon();
+  int i;
+  for( i=0; i < n; ++i )
+  { RegSet_T c = RegSet_Concat(res,a);
+    RegSet_Free(res);
+    res = c;
+  }
+  return res;
+}
+
+RegSet_T RegSet_Plus_range(RegSet_T a, int lwr, int upr)
+/* iteration { a } lwr-times .. upr-times, lwr >= 0, upr >= 0 */
+{ RegSet_T res = RegSet_Plus_ntimes(a,lwr);
+  int i;
+  for( i=lwr+1; i <= upr; ++i )
+  { RegSet_T b = RegSet_Option(a);
+    RegSet_T c = RegSet_Concat(res,b);
+    RegSet_Free(b);
+    RegSet_Free(res);
+    res = c;
+  }
+  return res;
+}
+
 bool RegSet_isChar(RegSet_T a)
 /* a = 'x' ? */
 { faNode s0 = fst(faNode,RegSet_IMP(a)->Nodes);
@@ -893,7 +919,7 @@ void Scn_dfnDyckToken
 { scn_t scn = Scn_IMP(dyck);
   Scn_dfnToken_aux(&CurScnDfn,name,tok_flags,left,Scn_defining);
   CurScnDfn.dyckpat[CurScnDfn.topEntry-1] = 
-    ( scn == (scn_t)NULL ) ? (scn_t)NULL : scn;
+    /*( scn == (scn_t)NULL ) ? (scn_t)NULL :*/ scn;
 }
 
 void Scn_dfnDyckToken_reentrant
@@ -906,7 +932,7 @@ void Scn_dfnDyckToken_reentrant
   BUG_NULL(curdfn);
   Scn_dfnToken_aux(curdfn,name,tok_flags,left,C_True);
   curdfn->dyckpat[curdfn->topEntry-1] = 
-    ( scn == (scn_t)NULL ) ? (scn_t)NULL : scn;
+    /*( scn == (scn_t)NULL ) ? (scn_t)NULL :*/ scn;
 }
 
 static void pConflicts(ScnDfn_T scndfn, List(faNode) nodes)
@@ -1075,6 +1101,42 @@ static Scn_T ScnTable (ScnDfn_T scndfn, RegSet_T scanner)
 
 /* -- graph printer -- */
 
+static void pGraphList
+     (
+       List(Abs_T) x, int Indent, 
+       void (*pMember)(Abs_T x, StdCPtr any), StdCPtr any
+     )
+{ void (*prMsg)(c_string msg) = ((ScnDfn_T)any)->prMsg;
+  char buf[STD_BUFFLEN+1]; int i;
+  if( prMsg == (void (*)(c_string msg))NULL )
+    prMsg = prMsg_stdout;
+  (*prMsg)("[");
+  if (Indent >= 0 && !empty(x)) 
+  {
+    sprintf(buf,"\n%*s",Indent,"");
+    (*prMsg)(buf);
+  }
+  for (i = 0; !empty(x); x = rst(x), i +=1 )
+  {
+    (*pMember)(fst(Abs_T,x),any);
+    if (!empty(rst(x)))
+      if (Indent >= 0 || (i+1) % 4 == 0)
+      { (*prMsg)(","); 
+        sprintf(buf,"\n%*s",(Indent>=0?Indent:7),"");
+        (*prMsg)(buf);
+      }
+      else
+        (*prMsg)(", ");
+      else
+        if (Indent >= 0)
+        {
+          sprintf(buf,"\n%*s",Indent,"");
+          (*prMsg)(buf);
+        }
+  }
+  (*prMsg)("]");
+}
+
 static void pSource(faNode x, ScnDfn_T scndfn)
 { void (*prMsg)(c_string msg) = scndfn->prMsg;
   char buf[STD_BUFFLEN+1];
@@ -1149,13 +1211,13 @@ static void pNfaEdge(nfaEdge x, ScnDfn_T scndfn)
     sprintf(buf,"({%08lx..%08lx}, ", x->nfa_lower, x->nfa_upper);
     (*prMsg)(buf);
   }
-  pListEx(x->nfa_toNodes,-1,(void (*)(Abs_T x,StdCPtr any))pSource,scndfn);
+  pGraphList(x->nfa_toNodes,-1,(void (*)(Abs_T x,StdCPtr any))pSource,scndfn);
   (*prMsg)(")");
 }
 
 static void pNfaEdges(List(nfaEdge) x, ScnDfn_T scndfn)
 {
-  pListEx(x,-1,(void (*)(Abs_T x,StdCPtr any))pNfaEdge,scndfn);
+  pGraphList(x,-1,(void (*)(Abs_T x,StdCPtr any))pNfaEdge,scndfn);
 }
 
 static void pNode(faNode x, ScnDfn_T scndfn)
@@ -1167,9 +1229,9 @@ static void pNode(faNode x, ScnDfn_T scndfn)
   (*prMsg)(buf);
   sprintf(buf,"(%2d %2d) ", x->flag1, x->flag2);
   (*prMsg)(buf);
-  pListEx(x->Source,-1,(void (*)(Abs_T x,StdCPtr any))pSource,scndfn);
+  pGraphList(x->Source,-1,(void (*)(Abs_T x,StdCPtr any))pSource,scndfn);
   (*prMsg)("\n      ");
-  pListEx(x->Edges,-1,(void (*)(Abs_T x,StdCPtr any))pEdge,scndfn);
+  pGraphList(x->Edges,-1,(void (*)(Abs_T x,StdCPtr any))pEdge,scndfn);
 }
 
 void RegSet_Print(RegSet_T x)
@@ -1180,7 +1242,7 @@ void RegSet_Print(RegSet_T x)
     prMsg = prMsg_stdout;
   sprintf(buf,"RegSet_T %d =\n",RegSet_IMP(x)->id);
   (*prMsg)(buf);
-  pListEx
+  pGraphList
   (
     RegSet_IMP(x)->Nodes,0,(void (*)(Abs_T x,StdCPtr any))pNode,&CurScnDfn
   );
@@ -1197,7 +1259,7 @@ void RegSet_Print_reentrant(ScnDfn_T curdfn, RegSet_T x)
     prMsg = prMsg_stdout;
   sprintf(buf,"RegSet_T %d =\n",RegSet_IMP(x)->id);
   (*prMsg)(buf);
-  pListEx(RegSet_IMP(x)->Nodes,0,(void (*)(Abs_T x,StdCPtr any))pNode,curdfn);
+  pGraphList(RegSet_IMP(x)->Nodes,0,(void (*)(Abs_T x,StdCPtr any))pNode,curdfn);
   (*prMsg)("\n");
 }
 
