@@ -439,6 +439,21 @@ static c_bool SD_gendoc_did(HPat_T pHPat)
         {
           Sink_printf(pSnk,":%s",GLS_Tok_string(pDId));
         }
+        else
+        if( styxQlxGrp_pgrp(pDGrp,&pDId) )
+        {
+          Sink_printf(pSnk,":[push], %s",GLS_Tok_string(pDId));
+        }
+        else
+        if( styxQlxGrp_pigrp(pDGrp) )
+        {
+          Sink_printf(pSnk,":[push], [initial]");
+        }
+        else
+        if( styxQlxGrp_pop(pDGrp) )
+        {
+          Sink_printf(pSnk,":[pop]");
+        }
         szID = Sink_close(pSnk);
         fprintf(pStyDoc->pSysOut,"%s",szID);
         FreeMem(szID);
@@ -817,7 +832,14 @@ static void SD_collectSubExps(styxExp e, SET(styxExp) pSubExps)
 
 static void SD_evalQExp(styxExp e, ROW(symbol) l, SET(styxExp) pSubExps)
 // Meta-Symbols: ()|+{}[]- and ..
-{ styxExp exp1, exp2, exp3; GLS_Tok tok;
+{ styxExp exp1, exp2, exp3; styxLimit limit; GLS_Tok tok;
+  if( styxExp_quot(e,&exp1,&exp2) )
+  {
+    SD_evalQExp(exp1,l,pSubExps);
+    OT_PUSH(stringToSymbol("/"),l);
+    SD_evalQExp(exp2,l,pSubExps);
+  }
+  else
   if( styxExp_dyck(e,&exp1,&exp2,&exp3) )
   { 
      OT_PUSH(stringToSymbol("<"),l);
@@ -829,6 +851,20 @@ static void SD_evalQExp(styxExp e, ROW(symbol) l, SET(styxExp) pSubExps)
      OT_PUSH(stringToSymbol(">"),l);
   }
   else
+  if( styxExp_spat(e,&exp1,&tok,&exp2) || styxExp_epat(e,&exp1,&tok,&exp2) )
+  { 
+    if( styxExp_spat(e,_,_,_) )
+      OT_PUSH(stringToSymbol("<="),l);
+    else
+      OT_PUSH(stringToSymbol("<?"),l);
+    SD_evalQExp(exp1,l,pSubExps);
+    OT_PUSH(stringToSymbol(">"),l);
+    OT_PUSH(GLS_Tok_symbol(tok),l);
+    OT_PUSH(stringToSymbol("<"),l);
+    SD_evalQExp(exp2,l,pSubExps);
+    OT_PUSH(stringToSymbol(">"),l);
+  }
+  else
   if( styxExp_union(e,&exp1,&exp2) )
   { 
     if( HS_MBR_ELM(exp1,pSubExps) )
@@ -892,14 +928,14 @@ static void SD_evalQExp(styxExp e, ROW(symbol) l, SET(styxExp) pSubExps)
     OT_PUSH(stringToSymbol("]"),l);
   }
   else
-  if( styxExp_star(e,&exp1) )
+  if( styxExp_star(e,&exp1) || styxExp_plus0(e,&exp1) )
   { 
     OT_PUSH(stringToSymbol("{"),l);
     SD_evalQExp(exp1,l,pSubExps);
     OT_PUSH(stringToSymbol("}"),l);
   }
   else
-  if( styxExp_plus(e,&exp1) )
+  if( styxExp_plus(e,&exp1) || styxExp_plusn(e,&exp1,&limit) )
   { 
     if( HS_MBR_ELM(exp1,pSubExps) )
     {
@@ -908,7 +944,29 @@ static void SD_evalQExp(styxExp e, ROW(symbol) l, SET(styxExp) pSubExps)
       OT_PUSH(stringToSymbol(")"),l);
     }
     else SD_evalQExp(exp1,l,pSubExps);
-    OT_PUSH(stringToSymbol("+"),l);
+    if( styxExp_plus(e,_) )
+      OT_PUSH(stringToSymbol("+"),l);
+    else
+    { styxOptNat optnat;
+      if( styxLimit_ntime(limit,&tok) )
+        OT_PUSH(GLS_Tok_symbol(tok),l);
+      else
+      if( styxLimit_range(limit,&tok,&optnat) )
+      {
+        if( styxOptNat_non(optnat) )
+        {
+          OT_PUSH(stringToSymbol(">="),l);
+          OT_PUSH(GLS_Tok_symbol(tok),l);
+        }
+        else
+        {
+          OT_PUSH(GLS_Tok_symbol(tok),l);
+          OT_PUSH(stringToSymbol(","),l);
+          assert( styxOptNat_nat(optnat,&tok), "");
+          OT_PUSH(GLS_Tok_symbol(tok),l);
+        }
+      }
+    }
   }
   else
   if( styxExp_range(e,&exp1,&exp2) )
@@ -933,7 +991,7 @@ static void SD_evalQExp(styxExp e, ROW(symbol) l, SET(styxExp) pSubExps)
     OT_PUSH(GLS_Tok_symbol(tok),l);
   }
   else 
-  if( !styxExp_nul(e) ) C_BUG;
+  if( !styxExp_non(e) ) C_BUG;
 }
 
 static void SD_load_com(StyDoc_T pStyDoc)
@@ -997,7 +1055,8 @@ static void SD_load_com(StyDoc_T pStyDoc)
           {
             assert0(   styxQlxDfn_defn((styxQlxDfn)t,_,_,_,&pIde,_,_)
                     || styxQlxDfn_igrp((styxQlxDfn)t,&pIde)
-                    || styxQlxDfn_xgrp((styxQlxDfn)t,&pIde), "");
+                    || styxQlxDfn_xgrp((styxQlxDfn)t,&pIde)
+                    || styxQlxDfn_mgrp((styxQlxDfn)t,&pIde,_), "");
             if( !MAP_defined(pStyDoc->pDfnCom,GLS_Tok_symbol(pIde)) )
             {
               pComments = OT_CREATE_ADT(PT_Term);
@@ -1075,7 +1134,8 @@ static void SD_load_lex(GLS_Lst(styxQlxDfn) pQDfns, StyDoc_T pStyDoc)
         MAP_dfndom(pStyDoc->pTMap,pTSym,pQDfn);
     }
     else
-    if( styxQlxDfn_igrp(pQDfn,&pIde) || styxQlxDfn_xgrp(pQDfn,&pIde) )
+    if( styxQlxDfn_igrp(pQDfn,&pIde) || styxQlxDfn_xgrp(pQDfn,&pIde) ||
+        styxQlxDfn_mgrp(pQDfn,&pIde,_) )
     {
       if( ! MAP_defined(pStyDoc->pGMap,GLS_Tok_symbol(pIde)) )
         MAP_dfndom(pStyDoc->pGMap,GLS_Tok_symbol(pIde),pQDfn);
@@ -1400,7 +1460,7 @@ static void SD_load_ntlist
 }
 
 static c_bool SD_splitClass(StyDoc_T pStyDoc, long lClsIdx)
-/* create separat rules for each nonterminal */
+/* create separate rules for each nonterminal */
 { symbol pClsSym = stringToSymbol(PLR_symName
                    (
                      pStyDoc->pTab, PLR_tokenCnt(pStyDoc->pTab) + lClsIdx
@@ -1564,13 +1624,14 @@ static c_bool SD_load(StyDoc_T* ppStyDoc)
   { styxSource          pSrc;
     GLS_Lst(styxQlxDfn) pQDfns;
     GLS_Lst(styxDfn)    pDfns;
+    styxOptCfg          pOptCfg;
     GLS_Tok             pIde;
     // fill documentation base
     styx_Start_Source(pStyDoc->pTree,&pSrc);
-    styxSource_root(pSrc,&pIde,&pQDfns,&pDfns);
+    styxSource_root(pSrc,&pIde,&pQDfns,&pOptCfg);
     SD_load_com(pStyDoc);
     SD_load_lex(pQDfns,pStyDoc);
-    if( ! GLS_EMPTY(pDfns) )
+    if( styxOptCfg_cfg(pOptCfg,&pDfns) && ! GLS_EMPTY(pDfns) )
     {
       pStyDoc->pTab = PLR_getTab_env(binpath,GLS_Tok_string(pIde));
       if( pStyDoc->pTab != (PLR_Tab)NULL &&
